package com.sun.corba.se.spi.logging;

import java.util.logging.LogRecord;
import java.util.logging.Level;
import java.util.logging.Logger;

public abstract class LogWrapperBase
{
    protected Logger logger;
    protected String loggerName;
    
    protected LogWrapperBase(Logger logger) {
        this.logger = logger;
        this.loggerName = logger.getName();
    }
    
    protected void doLog(Level level, String msg, Object[] parameters, Class clazz, Throwable thrown) {
        LogRecord record = new LogRecord(level, msg);
        if (parameters != null) {
            record.setParameters(parameters);
        }
        this.inferCaller(clazz, record);
        record.setThrown(thrown);
        record.setLoggerName(this.loggerName);
        record.setResourceBundle(this.logger.getResourceBundle());
        this.logger.log(record);
    }
    
    private void inferCaller(Class clazz, LogRecord logRecord) {
        StackTraceElement[] stackTrace = new Throwable().getStackTrace();
        StackTraceElement stackTraceElement = null;
        String name = clazz.getName();
        String name2 = LogWrapperBase.class.getName();
        int i = 0;
        while (i < stackTrace.length) {
            stackTraceElement = stackTrace[i];
            String className = stackTraceElement.getClassName();
            if (!className.equals(name) && !className.equals(name2)) {
                break;
            }
            ++i;
        }
        if (i < stackTrace.length) {
            logRecord.setSourceClassName(stackTraceElement.getClassName());
            logRecord.setSourceMethodName(stackTraceElement.getMethodName());
        }
    }
    
    protected void doLog(Level level, String s, Class clazz, Throwable t) {
        this.doLog(level, s, null, clazz, t);
    }
}
